@@ -22,40 +22,37 @@
 
 package UsersConfig;
 
-use base qw(Net::DBus::Object);
+use base qw(StbObject);
 use Net::DBus::Exporter ($Utils::Backend::DBUS_PREFIX);
-use Utils::Backend;
 use Users::Users;
 use Users::Shells;
 
 my $OBJECT_NAME = "UsersConfig";
 my $OBJECT_PATH = "$Utils::Backend::DBUS_PATH/$OBJECT_NAME";
+my $format = [[ "array", [ "struct", "uint32", "string", "string", "int32", "int32", [ "array", "string"], "string", "string" ]],
+              ["array", "string" ], "int32", "int32", "int32", "string", "string", "int32" ];
 
 sub new
 {
-  my $class   = shift;
-  my $service = shift;
-  my $self    = $class->SUPER::new ($service, $OBJECT_PATH);
+  my $class = shift;
+  my $self  = $class->SUPER::new ($OBJECT_PATH, $OBJECT_NAME);
 
   bless $self, $class;
 
-  Utils::Monitor::monitor_files (&Users::Users::get_files (),
-                                 $self, $OBJECT_NAME, "changed");
+#  Utils::Monitor::monitor_files (&Users::Users::get_files (),
+#                                 $self, $OBJECT_NAME, "changed");
   return $self;
 }
 
-dbus_method ("get", [],
-             [[ "array", [ "struct", "uint32", "string", "string", "int32", "int32", [ "array", "string"], "string", "string" ]],
-              ["array", "string" ], "int32", "int32", "int32", "string", "string", "int32" ]);
-dbus_method ("set",
-             [[ "array", [ "struct", "uint32", "string", "string", "int32", "int32", [ "array", "string"], "string", "string" ]],
-              ["array", "string" ], "int32", "int32", "int32", "string", "string", "int32" ], []);
-dbus_signal ("changed", []);
+dbus_method ("get", [], $format);
+dbus_method ("set", $format, []);
+#dbus_signal ("changed", []);
 
 sub get
 {
   my ($self) = @_;
   my $logindefs, $users, $use_md5, $shells;
+  $self->SUPER::reset_counter ();
 
   $use_md5 = &Users::Users::get_use_md5 ();
   $logindefs = &Users::Users::get_logindefs ();
@@ -70,6 +67,7 @@ sub get
 sub set
 {
   my ($self, @config) = @_;
+  $self->SUPER::reset_counter ();
 
   Users::Users::set ($config[0]);
   Users::Shells::set ($config[1]);
@@ -80,4 +78,6 @@ sub set
                                 "group"       => $config[7]});
 }
 
+my $config = UsersConfig->new ();
+
 1;
