@@ -39,6 +39,7 @@ my $PLATFORM_INFO = {
   "ubuntu-6.06"     => [ "Ubuntu Linux", "6.06", "Dapper" ],
   "ubuntu-6.10"     => [ "Ubuntu Linux", "6.10", "Edgy" ],
   "ubuntu-7.04"     => [ "Ubuntu Linux", "7.04", "Feisty" ],
+  "ubuntu-7.10"     => [ "Ubuntu Linux", "7.10", "Gutsy" ],
   "redhat-5.2"      => [ "Red Hat Linux", "5.2", "Apollo" ],
   "redhat-6.0"      => [ "Red Hat Linux", "6.0", "Hedwig" ],
   "redhat-6.1"      => [ "Red Hat Linux", "6.1", "Cartman" ],
@@ -71,6 +72,9 @@ my $PLATFORM_INFO = {
   "slackware-10.0.0" => [ "Slackware", "10.0.0", "" ],
   "slackware-10.1.0" => [ "Slackware", "10.1.0", "" ],
   "slackware-10.2.0" => [ "Slackware", "10.2.0", "" ],
+  "slackware-11.0.0" => [ "Slackware", "11.0.0", "" ],
+  "slackware-12.0.0" => [ "Slackware", "12.0.0", "" ],
+  "bluewhite64-12.0.0" => [ "Bluewhite64", "12.0.0", "" ],
   "freebsd-4"       => [ "FreeBSD", "4", "" ],
   "freebsd-5"       => [ "FreeBSD", "5", "" ],
   "freebsd-6"       => [ "FreeBSD", "6", "" ],
@@ -138,11 +142,15 @@ sub ensure_distro_map
      "slackware-10.0.0" => "slackware-9.1.0",
      "slackware-10.1.0" => "slackware-9.1.0",
      "slackware-10.2.0" => "slackware-9.1.0",
+     "slackware-11.0.0" => "slackware-9.1.0",
+     "slackware-12.0.0" => "slackware-9.1.0",
+     "bluewhite64-12.0.0" => "slackware-9.1.0",
      "suse-9.1"         => "suse-9.0",
      "ubuntu-5.04"      => "debian-3.0",
      "ubuntu-5.10"      => "debian-3.0",
      "ubuntu-6.06"      => "debian-3.0",
      "ubuntu-6.10"      => "debian-3.0",
+     "ubuntu-7.10"      => "ubuntu-7.04",
      "vine-3.1"         => "vine-3.0",
      "vlos-1.2"         => "gentoo",
      "nexenta-1.0"      => "solaris-2.11",
@@ -370,6 +378,7 @@ sub guess
                   [ \&check_distro_file, "/etc/redhat-release", "redhat", "^Red Hat Linux.*\\s+(\\S+)" ],
                   [ \&check_distro_file, "/etc/openna-release", "openna", "^OpenNA (\\S+)" ],
                   [ \&check_distro_file, "/etc/slackware-version", "slackware", "^Slackware (\\S+)" ],
+                  [ \&check_distro_file, "/etc/bluewhite64-version", "bluewhite64", "^Bluewhite64 (\\S+)" ],
                   [ \&check_distro_file, "/etc/vlos-release", "vlos", "^VLOS.*\\s+(\\S+)" ],
                   [ \&check_file_exists, "/usr/portage", "gentoo" ],
                   [ \&check_distro_file, "/etc/pld-release", "pld", "^(\\S+) PLD Linux" ],
